@@ -34,7 +34,7 @@ of command-line interface (CLI) programs.
 
 See https://plumbum.readthedocs.io for full details
 """
-from plumbum.commands import ProcessExecutionError, CommandNotFound, ProcessTimedOut
+from plumbum.commands import ProcessExecutionError, CommandNotFound, ProcessTimedOut, ProcessLineTimedOut
 from plumbum.commands import FG, BG, TEE, TF, RETCODE, ERROUT, NOHUP
 from plumbum.path import Path, LocalPath, RemotePath
 from plumbum.machines import local, BaseRemoteMachine, SshMachine, PuttyMachine
