@@ -1,6 +1,6 @@
 from __future__ import absolute_import
 
 from .switches import SwitchError, switch, autoswitch, SwitchAttr, Flag, CountOf, positional
-from .switches import Range, Set, ExistingDirectory, ExistingFile, NonexistentPath, Predicate
+from .switches import Range, Set, ExistingDirectory, ExistingFile, NonexistentPath, Predicate, CSV
 from .application import Application
 from .config import ConfigINI, Config
