@@ -139,8 +139,12 @@ class Progress(ProgressBase):
             print()
 
     def __str__(self):
-        percent = max(self.value, 0) / self.length
         width = get_terminal_size(default=(0, 0))[0]
+        if self.length == 0:
+            self.width = 0
+            return "0/0 complete"
+
+        percent = max(self.value, 0) / self.length
         ending = ' ' + (self.str_time_remaining()
                         if self.timer else '{0} of {1} complete'.format(
                             self.value, self.length))
@@ -175,7 +179,7 @@ class Progress(ProgressBase):
 
 
 class ProgressIPy(ProgressBase):  # pragma: no cover
-    HTMLBOX = '<div class="widget-hbox widget-progress"><div class="widget-label" style="display:block;">{}</div></div>'
+    HTMLBOX = '<div class="widget-hbox widget-progress"><div class="widget-label" style="display:block;">{0}</div></div>'
 
     def __init__(self, *args, **kargs):
 
