@@ -1,4 +1,4 @@
 from plumbum.commands.base import shquote, shquote_list, BaseCommand, ERROUT, ConcreteCommand
 from plumbum.commands.modifiers import ExecutionModifier, Future, FG, BG, TEE, TF, RETCODE, NOHUP
 from plumbum.commands.processes import run_proc
-from plumbum.commands.processes import ProcessExecutionError, ProcessTimedOut, CommandNotFound
+from plumbum.commands.processes import ProcessExecutionError, ProcessTimedOut, CommandNotFound, ProcessLineTimedOut
