@@ -1,4 +1,6 @@
+import shlex
 import subprocess
+import sys
 import functools
 from contextlib import contextmanager
 from plumbum.commands.processes import run_proc, iter_lines
@@ -24,21 +26,12 @@ _funnychars = '"`$\\'
 
 def shquote(text):
     """Quotes the given text with shell escaping (assumes as syntax similar to ``sh``)"""
-    if not text:
-        return "''"
     text = six.str(text)
-    if not text:
-        return "''"
-    for c in text:
-        if c not in _safechars:
-            break
+    if sys.version_info >= (3, 3):
+        return shlex.quote(text)
     else:
-        return text
-    if "'" not in text:
-        return "'" + text + "'"
-    res = six.str("").join(
-        (six.str('\\' + c) if c in _funnychars else c) for c in text)
-    return six.str('"') + res + six.str('"')
+        import pipes
+        return pipes.quote(text)
 
 
 def shquote_list(seq):
@@ -448,10 +441,10 @@ class BaseRedirection(BaseCommand):
 
         if self.KWARG in kwargs and kwargs[self.KWARG] not in (PIPE, None):
             raise RedirectionError("%s is already redirected" % (self.KWARG, ))
+        if isinstance(self.file, RemotePath):
+            raise TypeError("Cannot redirect to/from remote paths")
         if isinstance(self.file, six.string_types + (LocalPath, )):
             f = kwargs[self.KWARG] = open(str(self.file), self.MODE)
-        elif isinstance(self.file, RemotePath):
-            raise TypeError("Cannot redirect to/from remote paths")
         else:
             kwargs[self.KWARG] = self.file
             f = None
