@@ -8,12 +8,12 @@ from plumbum.lib import IS_WIN32, six
 try:
     from queue import Queue, Empty as QueueEmpty
 except ImportError:
-    from Queue import Queue, Empty as QueueEmpty # type: ignore
+    from Queue import Queue, Empty as QueueEmpty  # type: ignore
 
 try:
     from io import StringIO
 except ImportError:
-    from cStringIO import StringIO # type: ignore
+    from cStringIO import StringIO  # type: ignore
 
 
 #===================================================================================================
@@ -23,17 +23,22 @@ def _check_process(proc, retcode, timeout, stdout, stderr):
     proc.verify(retcode, timeout, stdout, stderr)
     return proc.returncode, stdout, stderr
 
-def _iter_lines(proc, decode, linesize):
+
+def _iter_lines(proc, decode, linesize, line_timeout=None):
     try:
         from selectors import DefaultSelector, EVENT_READ
     except ImportError:
         # Pre Python 3.4 implementation
         from select import select
+
         def selector():
             while True:
-                rlist, _, _ = select([proc.stdout, proc.stderr], [], [])
+                rlist, _, _ = select([proc.stdout, proc.stderr], [], [], line_timeout)
+                if not rlist and line_timeout:
+                    raise ProcessLineTimedOut("popen line timeout expired", getattr(proc, "argv", None), getattr(proc, "machine", None))
                 for stream in rlist:
-                    yield (stream is proc.stderr), decode(stream.readline(linesize))
+                    yield (stream is proc.stderr), decode(
+                        stream.readline(linesize))
     else:
         # Python 3.4 implementation
         def selector():
@@ -41,7 +46,10 @@ def _iter_lines(proc, decode, linesize):
             sel.register(proc.stdout, EVENT_READ, 0)
             sel.register(proc.stderr, EVENT_READ, 1)
             while True:
-                for key, mask in sel.select():
+                ready = sel.select(line_timeout)
+                if not ready and line_timeout:
+                    raise ProcessLineTimedOut("popen line timeout expired", getattr(proc, "argv", None), getattr(proc, "machine", None))
+                for key, mask in ready:
                     yield key.data, decode(key.fileobj.readline(linesize))
 
     for ret in selector():
@@ -63,6 +71,7 @@ class ProcessExecutionError(EnvironmentError):
     <plumbum.commands.run_proc>`. It contains the process' return code, stdout, and stderr, as
     well as the command line used to create the process (``argv``)
     """
+
     def __init__(self, argv, retcode, stdout, stderr):
         Exception.__init__(self, argv, retcode, stdout, stderr)
         self.argv = argv
@@ -73,51 +82,76 @@ class ProcessExecutionError(EnvironmentError):
             stderr = six.ascii(stderr)
         self.stdout = stdout
         self.stderr = stderr
+
     def __str__(self):
-        stdout = "\n         | ".join(str(self.stdout).splitlines())
-        stderr = "\n         | ".join(str(self.stderr).splitlines())
-        lines = ["Command line: %r" % (self.argv,), "Exit code: %s" % (self.retcode)]
+        from plumbum.commands.base import shquote_list
+        stdout =      "\n              | ".join(str(self.stdout).splitlines())
+        stderr =      "\n              | ".join(str(self.stderr).splitlines())
+        cmd = " ".join(shquote_list(self.argv))
+        lines = ["Unexpected exit code: ", str(self.retcode)]
+        cmd =         "\n              | ".join(cmd.splitlines())
+        lines +=     ["\nCommand line: | ", cmd]
         if stdout:
-            lines.append("Stdout:  | %s" % (stdout,))
+            lines += ["\nStdout:       | ", stdout]
         if stderr:
-            lines.append("Stderr:  | %s" % (stderr,))
-        return "\n".join(lines)
+            lines += ["\nStderr:       | ", stderr]
+        return "".join(lines)
+
 
 class ProcessTimedOut(Exception):
     """Raises by :func:`run_proc <plumbum.commands.run_proc>` when a ``timeout`` has been
     specified and it has elapsed before the process terminated"""
+
     def __init__(self, msg, argv):
         Exception.__init__(self, msg, argv)
         self.argv = argv
 
+
+class ProcessLineTimedOut(Exception):
+    """Raises by :func:`iter_lines <plumbum.commands.iter_lines>` when a ``line_timeout`` has been
+    specified and it has elapsed before the process yielded another line"""
+    def __init__(self, msg, argv, machine):
+        Exception.__init__(self, msg, argv, machine)
+        self.argv = argv
+        self.machine = machine
+
+
 class CommandNotFound(AttributeError):
     """Raised by :func:`local.which <plumbum.machines.local.LocalMachine.which>` and
     :func:`RemoteMachine.which <plumbum.machines.remote.RemoteMachine.which>` when a
     command was not found in the system's ``PATH``"""
+
     def __init__(self, program, path):
         Exception.__init__(self, program, path)
         self.program = program
         self.path = path
 
+
 #===================================================================================================
 # Timeout thread
 #===================================================================================================
 class MinHeap(object):
-    def __init__(self, items = ()):
+    def __init__(self, items=()):
         self._items = list(items)
         heapq.heapify(self._items)
+
     def __len__(self):
         return len(self._items)
+
     def push(self, item):
         heapq.heappush(self._items, item)
+
     def pop(self):
         heapq.heappop(self._items)
+
     def peek(self):
         return self._items[0]
 
+
 _timeout_queue = Queue()
 _shutting_down = False
 
+
 def _timeout_thread_func():
     waiting = MinHeap()
     try:
@@ -128,7 +162,7 @@ def _timeout_thread_func():
             else:
                 timeout = None
             try:
-                proc, time_to_kill = _timeout_queue.get(timeout = timeout)
+                proc, time_to_kill = _timeout_queue.get(timeout=timeout)
                 if proc is SystemExit:
                     # terminate
                     return
@@ -154,27 +188,34 @@ def _timeout_thread_func():
         else:
             raise
 
-bgthd = Thread(target = _timeout_thread_func, name = "PlumbumTimeoutThread")
+
+bgthd = Thread(target=_timeout_thread_func, name="PlumbumTimeoutThread")
 bgthd.setDaemon(True)
 bgthd.start()
 
+
 def _register_proc_timeout(proc, timeout):
     if timeout is not None:
         _timeout_queue.put((proc, time.time() + timeout))
 
+
 def _shutdown_bg_threads():
     global _shutting_down
     _shutting_down = True
-    _timeout_queue.put((SystemExit, 0))
-    # grace period
-    bgthd.join(0.1)
+    # Make sure this still exists (don't throw error in atexit!)
+    if _timeout_queue:
+        _timeout_queue.put((SystemExit, 0))
+        # grace period
+        bgthd.join(0.1)
+
 
 atexit.register(_shutdown_bg_threads)
 
+
 #===================================================================================================
 # run_proc
 #===================================================================================================
-def run_proc(proc, retcode, timeout = None):
+def run_proc(proc, retcode, timeout=None):
     """Waits for the given process to terminate, with the expected exit code
 
     :param proc: a running Popen-like object, with all the expected methods.
@@ -209,7 +250,20 @@ def run_proc(proc, retcode, timeout = None):
 #===================================================================================================
 # iter_lines
 #===================================================================================================
-def iter_lines(proc, retcode = 0, timeout = None, linesize = -1, _iter_lines = _iter_lines):
+
+BY_POSITION = object()
+BY_TYPE = object()
+DEFAULT_ITER_LINES_MODE = BY_POSITION
+
+
+def iter_lines(proc,
+               retcode=0,
+               timeout=None,
+               linesize=-1,
+               line_timeout=None,
+               mode=None,
+               _iter_lines=_iter_lines,
+               ):
     """Runs the given process (equivalent to run_proc()) and yields a tuples of (out, err) line pairs.
     If the exit code of the process does not match the expected one, :class:`ProcessExecutionError
     <plumbum.commands.ProcessExecutionError>` is raised.
@@ -226,8 +280,16 @@ def iter_lines(proc, retcode = 0, timeout = None, linesize = -1, _iter_lines = _
     :param linesize: Maximum number of characters to read from stdout/stderr at each iteration.
                     ``-1`` (default) reads until a b'\\n' is encountered.
 
+    :param line_timeout: The maximal amount of time (in seconds) to allow between consecutive lines in either stream.
+                    Raise an :class:`ProcessLineTimedOut <plumbum.commands.ProcessLineTimedOut>` if the timeout has
+                    been reached. ``None`` means no timeout is imposed.
+
     :returns: An iterator of (out, err) line tuples.
     """
+    if mode is None:
+        mode = DEFAULT_ITER_LINES_MODE
+
+    assert mode in (BY_POSITION, BY_TYPE)
 
     encoding = getattr(proc, "custom_encoding", None)
     if encoding:
@@ -238,11 +300,19 @@ def iter_lines(proc, retcode = 0, timeout = None, linesize = -1, _iter_lines = _
     _register_proc_timeout(proc, timeout)
 
     buffers = [StringIO(), StringIO()]
-    for t, line in _iter_lines(proc, decode, linesize):
-        ret = [None, None]
-        ret[t] = line
+    for t, line in _iter_lines(proc, decode, linesize, line_timeout):
+
+        # verify that the proc hasn't timed out yet
+        proc.verify(timeout=timeout, retcode=None, stdout=None, stderr=None)
+
         buffers[t].write(line + "\n")
-        yield ret
+
+        if mode is BY_POSITION:
+            ret = [None, None]
+            ret[t] = line
+            yield tuple(ret)
+        elif mode is BY_TYPE:
+            yield (t + 1), line  # 1=stdout, 2=stderr
 
     # this will take care of checking return code and timeouts
     _check_process(proc, retcode, timeout, *(s.getvalue() for s in buffers))
