@@ -38,6 +38,7 @@ class Path(str, six.ABC):
         return self.join(other)
 
     __truediv__ = __div__
+    __getitem__ = __div__
 
     def __floordiv__(self, expr):
         """Returns a (possibly empty) list of paths that matched the glob-pattern under this path"""
@@ -259,13 +260,31 @@ class Path(str, six.ABC):
         return self.move(self.up() / newname)
 
     @abstractmethod
-    def copy(self, dst, override=False):
-        """Copies this path (recursively, if a directory) to the destination path. Raises TypeError if
-        dst exists and override is False."""
+    def copy(self, dst, override=None):
+        """Copies this path (recursively, if a directory) to the destination path "dst".
+        Raises TypeError if dst exists and override is False.
+        Will overwrite if override is True.
+        Will silently fail to copy if override is None (the default)."""
 
     @abstractmethod
-    def mkdir(self):
-        """Creates a directory at this path; if the directory already exists, silently ignore"""
+    def mkdir(self, mode=0o777, parents=True, exist_ok=True):
+        """
+        Creates a directory at this path.
+
+        :param mode: **Currently only implemented for local paths!** Numeric mode to use for directory
+                     creation, which may be ignored on some systems. The current implementation
+                     reproduces the behavior of ``os.mkdir`` (i.e., the current umask is first masked
+                     out), but this may change for remote paths. As with ``os.mkdir``, it is recommended
+                     to call :func:`chmod` explicitly if you need to be sure.
+        :param parents: If this is true (the default), the directory's parents will also be created if
+                        necessary.
+        :param exist_ok: If this is true (the default), no exception will be raised if the directory
+                         already exists (otherwise ``OSError``).
+
+        Note that the defaults for ``parents`` and ``exist_ok`` are the opposite of what they are in
+        Python's own ``pathlib`` - this is to maintain backwards-compatibility with Plumbum's behaviour
+        from before they were implemented.
+        """
 
     @abstractmethod
     def open(self, mode="r"):
@@ -273,13 +292,14 @@ class Path(str, six.ABC):
 
     @abstractmethod
     def read(self, encoding=None):
-        """returns the contents of this file. By default the data is binary (``bytes``), but you can
-        specify the encoding, e.g., ``'latin1'`` or ``'utf8'``"""
+        """returns the contents of this file as a ``str``. By default the data is read
+        as text, but you can specify the encoding, e.g., ``'latin1'`` or ``'utf8'``"""
 
     @abstractmethod
     def write(self, data, encoding=None):
-        """writes the given data to this file. By default the data is expected to be binary (``bytes``),
-        but you can specify the encoding, e.g., ``'latin1'`` or ``'utf8'``"""
+        """writes the given data to this file. By default the data is written as-is
+        (either text or binary), but you can specify the encoding, e.g., ``'latin1'``
+        or ``'utf8'``"""
 
     @abstractmethod
     def touch(self):
@@ -404,7 +424,7 @@ class Path(str, six.ABC):
     @property
     def parents(self):
         """Pathlib like sequence of ancestors"""
-        join = lambda x, y: self.__class__(x) / y
+        join = lambda x, y: self._form(x) / y
         as_list = (reduce(join, self.parts[:i], self.parts[0])
                    for i in range(len(self.parts) - 1, 0, -1))
         return tuple(as_list)
