@@ -2,7 +2,8 @@ import errno
 from contextlib import contextmanager
 from plumbum.path.base import Path, FSUser
 from plumbum.lib import _setdoc, six
-from plumbum.commands import shquote
+from plumbum.commands import shquote, ProcessExecutionError
+import sys
 
 try:  # Py3
     import urllib.request as urllib
@@ -40,6 +41,7 @@ class RemotePath(Path):
         windows = (remote.uname.lower() == "windows")
         normed = []
 
+        parts = tuple(map(str, parts))  # force the paths into string, so subscription works properly
         # Simple skip if path is absolute
         if parts[0] and parts[0][0] not in ("/", "\\"):
             cwd = (remote._cwd if hasattr(remote, '_cwd') else
@@ -232,8 +234,23 @@ class RemotePath(Path):
         self.remote._path_copy(self, dst)
 
     @_setdoc(Path)
-    def mkdir(self):
-        self.remote._path_mkdir(self)
+    def mkdir(self, mode=None, parents=True, exist_ok=True):
+        if parents and exist_ok:
+            self.remote._path_mkdir(self, mode=mode, minus_p=True)
+        else:
+            if parents and len(self.parts) > 1:
+                self.remote._path_mkdir(self.parent, mode=mode, minus_p=True)
+            try:
+                self.remote._path_mkdir(self, mode=mode, minus_p=False)
+            except ProcessExecutionError:
+                _, ex, _ = sys.exc_info()
+                if "File exists" in ex.stderr:
+                    if not exist_ok:
+                        raise OSError(
+                            errno.EEXIST, "File exists (on remote end)",
+                            str(self))
+                else:
+                    raise
 
     @_setdoc(Path)
     def read(self, encoding=None):
@@ -293,8 +310,18 @@ class RemotePath(Path):
                 "got %r" % (dst, ))
         self.remote._path_link(self, dst, True)
 
-    def open(self):
-        pass
+    def open(self, mode="r", bufsize=-1):
+        """
+        Opens this path as a file.
+
+        Only works for ParamikoMachine-associated paths for now.
+        """
+        if hasattr(self.remote, "sftp") and hasattr(self.remote.sftp, "open"):
+            return self.remote.sftp.open(self, mode, bufsize)
+        else:
+            raise NotImplementedError(
+                "RemotePath.open only works for ParamikoMachine-associated "
+                "paths for now")
 
     @_setdoc(Path)
     def as_uri(self, scheme='ssh'):
